#ifndef NLPSERVICE_H
#define NLPSERVICE_H

#ifdef __cplusplus
extern "C" {
#endif

typedef enum {
    NLP_SUCCESS=0,
    NLP_SESSION_ERROR, // session 错误
    NLP_NET_ERROR, // 网络错误
    NLP_SERVER_ERROR, // 服务错误或者不可用
    NLP_UNAUTHORIZED, // 权限限制，鉴权失败，无权访问
    NLP_REQUEST_TOO_MANY, // 请求频率过高
    NLP_REQUEST_FAILED, // 请求失败
    NLP_INPUT_TEXT_LENGTH_INVAILD, // 输入文本长度超限
    NLP_PARAM_ERROR, // 参数错误
} NlpResult;

typedef void* NlpSession;

typedef void (*NlpCallback) (const char* result, void* user_data);

NlpResult nlp_create_session(NlpSession* session); // 创建新的NLP会话

void nlp_destory_session(NlpSession session); // 销毁创建

NlpResult nlp_init_session(NlpSession session); // 初始化session，阻塞接口，可能会比较耗时

void nlp_set_result_callback(NlpSession session, NlpCallback callback, void* user_data); // 设置获取调用结果的callback函数

void nlp_set_context_size(NlpSession session, int size); // 设置上下文大小, -1为默认; 0为无; 1为1K,逐渐递增

void nlp_clear_context(NlpSession session); // 清除上下文

NlpResult nlp_text_chat(NlpSession session, const char* message); //以下接口均使用JsonCallback返回调用结果

const char* nlp_last_error_message();

#ifdef __cplusplus
}
#endif

#endif
